@@ -1,4 +1,4 @@
-START_URLS_TOPIC = 'start-topic-{}'
+START_URLS_TOPIC = '{}_start'
 
 SCHEDULER_DUPEFILTER_KEY = '{}:dupefilter'
 SCHEDULER_DUPEFILTER_CLASS = 'kafka_scrapy.dupefilter.RFPDupeFilter'
@@ -13,7 +13,7 @@ DUPEFILTER_KEY = 'dupefilter:%(timestamp)s'
 
 SCHEDULER_QUEUE_CLASS = 'kafka_scrapy.queues.KafkaQueue'
 KAFKA_DEFAULTS_HOST = 'localhost:9092'
-KAFKA_DEFAULTS_TOPIC = 'topic-{}'
+KAFKA_DEFAULTS_TOPIC = '{}'
 BLOOMFILTER_BLOCK = 1
 BLOOMFILTER_SIZE = 31
 BLOOMFILTER_SEED = 6
